==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fIfle.h <==
// class soot.coffi.Instruction_Ifle

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class a5043a59725daac5 soot_coffi_Instruction__5fIfle
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIfle_H_
#define _JC_soot_coffi_Instruction__5fIfle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIfle$sub_refs	_jc_soot_coffi_Instruction__5fIfle$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$sub_nonrefs	_jc_soot_coffi_Instruction__5fIfle$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$refs	_jc_soot_coffi_Instruction__5fIfle$refs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$nonrefs	_jc_soot_coffi_Instruction__5fIfle$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$object	_jc_soot_coffi_Instruction__5fIfle$object;

typedef const struct _jc_soot_coffi_Instruction__5fIfle$vmethods	_jc_soot_coffi_Instruction__5fIfle$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIfle$vtable	_jc_soot_coffi_Instruction__5fIfle$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIfle$vtype	_jc_soot_coffi_Instruction__5fIfle$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIfle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIfle$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIfle$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIfle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIfle$vmethods	soot_coffi_Instruction__5fIfle;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIfle$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIfle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfle$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfle$refs {
    _jc_soot_coffi_Instruction__5fIfle$sub_refs	soot_coffi_Instruction__5fIfle;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIfle$sub_nonrefs	soot_coffi_Instruction__5fIfle;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIfle$object {
	_jc_soot_coffi_Instruction__5fIfle$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIfle$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIfle$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIfle$vtype _jc_soot_coffi_Instruction__5fIfle$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIfle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIfle$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIfle_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fIfle.h <==
// class soot.coffi.Instruction_Ifle

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class a5043a59725daac5 soot_coffi_Instruction__5fIfle
// @dep_class f1ed2760eb94209e soot_coffi_Instruction__5fbranch
// @dep_class 6bcdce6545109d8e soot_coffi_Instruction__5fintbranch

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintbranch

#include "soot/coffi/Instruction__5fintbranch.h"

#ifndef _JC_soot_coffi_Instruction__5fIfle_H_
#define _JC_soot_coffi_Instruction__5fIfle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fIfle$sub_refs	_jc_soot_coffi_Instruction__5fIfle$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$sub_nonrefs	_jc_soot_coffi_Instruction__5fIfle$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$refs	_jc_soot_coffi_Instruction__5fIfle$refs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$nonrefs	_jc_soot_coffi_Instruction__5fIfle$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fIfle$object	_jc_soot_coffi_Instruction__5fIfle$object;

typedef const struct _jc_soot_coffi_Instruction__5fIfle$vmethods	_jc_soot_coffi_Instruction__5fIfle$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fIfle$vtable	_jc_soot_coffi_Instruction__5fIfle$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fIfle$vtype	_jc_soot_coffi_Instruction__5fIfle$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fIfle$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fIfle$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fIfle$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fIfle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fbranch$vmethods	soot_coffi_Instruction__5fbranch;
	_jc_soot_coffi_Instruction__5fintbranch$vmethods	soot_coffi_Instruction__5fintbranch;
	_jc_soot_coffi_Instruction__5fIfle$vmethods	soot_coffi_Instruction__5fIfle;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fIfle$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fIfle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfle$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfle$refs {
    _jc_soot_coffi_Instruction__5fIfle$sub_refs	soot_coffi_Instruction__5fIfle;
    _jc_soot_coffi_Instruction__5fintbranch$sub_refs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fbranch$sub_refs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fIfle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fIfle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fbranch$sub_nonrefs	soot_coffi_Instruction__5fbranch;
    _jc_soot_coffi_Instruction__5fintbranch$sub_nonrefs	soot_coffi_Instruction__5fintbranch;
    _jc_soot_coffi_Instruction__5fIfle$sub_nonrefs	soot_coffi_Instruction__5fIfle;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fIfle$object {
	_jc_soot_coffi_Instruction__5fIfle$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fIfle$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fIfle$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fIfle$vtype _jc_soot_coffi_Instruction__5fIfle$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fIfle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fIfle$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fIfle_H_ */
